<!DOCTYPE html>
<html lang="en">
<head>
  {% block head %}
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <title>{{ title|default('Test Report') }}</title>
  {% filter css %}
    {% block style %}
    {% include "html1/style.css" %}
    {% endblock %}
  {% endfilter %}
  </style>
  <script>
    {% block script %}
    {% endblock %}
  </script>
  {% endblock %}
</head>
<body>
  <header>
    {% block header %}
    <div class="container">
      <h1>{{ title|default('Test Report') }}</h1>
    </div>
    {% endblock %}
  </header>
  <main>
    {% block content %}{% endblock %}
  </main>
  <footer>
    {% block footer %}
    <div class="container">
      Generated by <a href="https://pypi.org/project/pytest-reporter-html1/">pytest-reporter-html1</a>
    </div>
    {% endblock %}
  </footer>
</body>
</html>
